"use client";

import Image from "next/image";
import { useCallback, useEffect, useState } from "react";

import { ContentLines } from "@/components/shared/content-lines";
import { Button } from "@/components/ui/button";
import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import useEmblaCarousel from "embla-carousel-react";
import { AnimatePresence, motion } from "framer-motion";
import { ArrowLeft, ArrowRight } from "lucide-react";
import Link from "next/link";

import BlurFade from "@/components/ui/blur-fade";
import { ImageBaseUrl } from "@/configs/api";
import { useBasicInfo } from "@/servers/data/use-basicinfo";
import { useLocale, useTranslations } from "next-intl";

function AboutClient() {
	const locale = useLocale() as Locale;
	const t = useTranslations();
	const isRTL = locale === "ar";
	const { texts } = useBasicInfo();

	const [selectedItem, setSelectedItem] = useState<any>();

	const [emblaRef, emblaApi] = useEmblaCarousel({
		align: "start",
		containScroll: "trimSnaps",
		direction: isRTL ? "rtl" : "ltr",
	});

	const [canScrollPrev, setCanScrollPrev] = useState(false);
	const [canScrollNext, setCanScrollNext] = useState(true);

	const scrollPrev = useCallback(() => emblaApi?.scrollPrev(), [emblaApi]);
	const scrollNext = useCallback(() => emblaApi?.scrollNext(), [emblaApi]);

	const onSelect = useCallback(() => {
		if (!emblaApi) return;
		setCanScrollPrev(emblaApi.canScrollPrev());
		setCanScrollNext(emblaApi.canScrollNext());
	}, [emblaApi]);

	useEffect(() => {
		setSelectedItem(texts?.about_company_first_section?.[0]);

	}, [texts]);

	useEffect(() => {
		if (!emblaApi) return;
		onSelect();
		emblaApi.on("select", onSelect);
		emblaApi.on("reInit", onSelect);
		return () => {
			emblaApi.off("select", onSelect);
			emblaApi.off("reInit", onSelect);
		};
	}, [emblaApi, onSelect]);

	return (
		texts?.about_company_first_section?.length > 0 &&
		<section className="overflow-hidden bg-custom-background-third">
			<div className="container relative mx-auto px-4 py-12 pb-2 lg:px-40">
				<div className="grid grid-cols-1 items-start gap-x-8 lg:grid-cols-12 mt-4">
					{/* Content */}
					<BlurFade
						key="content-fade"
						className={cn(
							"flex h-[412px] max-w-[674px] flex-col justify-around rounded-lg bg-custom-background-light px-6 py-6 shadow-[0_78px_34px_-45px_rgba(0,0,0,0.15)]",
							"lg:col-span-7",
							isRTL ? "lg:order-1" : "lg:order-2"
						)}
					>
						<div className={cn("flex h-full flex-col justify-between")}>
							<ContentLines
								title={t("About Us")}
								underlineColor="custom-primary-accent"
								textColor="text-primary-accent"
							/>

							<AnimatePresence mode='wait'>
								<motion.h3
									key={selectedItem?.text?.[locale]}
									initial={{ opacity: 0, y: 20 }}
									animate={{ opacity: 1, y: 0 }}
									exit={{ opacity: 0, y: -20 }}
									transition={{ duration: 0.3, delay: 0.3, ease: "easeInOut" }}
									className="text-4xl leading-tight text-custom-dark-veryDark"
								>
									{selectedItem?.text?.[locale]}
								</motion.h3>
							</AnimatePresence>
							<AnimatePresence mode='wait'>
								<motion.p
									key={selectedItem?.description?.[locale]}
									initial={{ opacity: 0, y: 20 }}
									animate={{ opacity: 1, y: 0 }}
									exit={{ opacity: 0, y: -20 }}
									transition={{ duration: 0.3, delay: 0.3, ease: "easeInOut" }}
									className="leading-relaxed text-custom-dark-light"
								>
									{selectedItem?.description?.[locale]}
								</motion.p>
							</AnimatePresence>

							<div className="flex flex-row gap-4">
								<motion.div
									whileHover={{ scale: 1.05 }}
									whileTap={{ scale: 0.95 }}
								>
									<Button className="h-[50px] rounded-[14px] bg-custom-gray px-6 py-4 text-white hover:bg-custom-gray/90 w-auto"
										asChild>
										<Link href={`/${locale}/projects`}>
											<AnimatePresence mode='wait'>
												<motion.span
													key={selectedItem?.text?.[locale]}
													initial={{ scale: 0.8 }}
													animate={{ scale: 1 }}
													exit={{ scale: 0.8 }}
												>
													{t("Details")}
												</motion.span>
											</AnimatePresence>
										</Link>
									</Button>
								</motion.div>
							</div>
						</div>
					</BlurFade>


					{/* Main image */}
					<BlurFade
						key="main-image-fade"
						className={cn(
							"relative lg:col-span-5",
							isRTL ? "lg:order-2" : "lg:order-1"
						)}
					>
						<motion.div
							className="absolute -left-4 -top-4 h-full w-full bg-custom-border rounded-lg"
							initial={{ opacity: 0, scale: 0.8 }}
							animate={{ opacity: 1, scale: 1 }}
							transition={{ duration: 0.5 }}
						/>
						<motion.div
							initial={{ opacity: 0, y: 20 }}
							animate={{ opacity: 1, y: 0 }}
							transition={{ duration: 0.5, delay: 0.2 }}
						>
							<Image
								src={ImageBaseUrl + selectedItem?.image}
								alt={""}
								width={487}
								height={577}
								className="relative z-10 h-[500px] w-[487px] rounded-lg object-cover drop-shadow-[2px_2px_2px_rgba(0,0,0,0.5)] filter"
							/>
						</motion.div>
					</BlurFade>

					{/* Carousel images - Updated container to handle navigation positioning */}
					<BlurFade
						key="carousel-fade"
						className={cn(
							"relative lg:bottom-16 lg:order-3 lg:col-span-9",
							isRTL ? "lg:col-start-2" : "lg:col-start-4"
						)}
					>
						<div className="relative">
							<div className="overflow-hidden" ref={emblaRef}>
								<div className="flex touch-pan-y">
									{texts?.about_company_first_section?.map((item: any, index: number) => (
										<motion.div
											key={index}
											className={cn("relative rounded-lg mr-4 min-w-0 flex-[0_0_33.333%] cursor-pointer",
												selectedItem?.image === item?.image ? "border-2 border-custom-primary-accent" : ""
											)}
											initial={{ opacity: 0, y: 20 }}
											animate={{ opacity: 1, y: 0 }}
											transition={{ duration: 0.5, delay: index * 0.1 }}
											onClick={() => setSelectedItem(item)}
										>
											<Image
												src={ImageBaseUrl + item?.image}
												alt={""}
												width={286}
												height={161}
												className="h-[161.28px] w-full rounded-lg object-cover drop-shadow-[3px_2px_2px_rgba(0,0,0,0.5)] filter"

											/>
											<div className="absolute inset-0 rounded-lg bg-gradient-to-t from-black/60 to-transparent" />
										</motion.div>
									))}
								</div>
							</div>

							{/* Updated Navigation Buttons positioning */}
							<motion.div
								className={cn(
									"absolute -bottom-12 z-[100] flex flex-row items-center gap-4 lg:bottom-0 lg:flex-col",
									isRTL ? "right-0 lg:-right-12" : "left-0 lg:-left-12"
								)}
								initial={{ opacity: 0 }}
								animate={{ opacity: 1 }}
								transition={{ duration: 0.5, delay: 0.5 }}
							>
								<motion.div
									whileHover={{ scale: 1.1 }}
									whileTap={{ scale: 0.9 }}
								>
									<Button
										variant="outline"
										size="icon"
										className="h-10 w-10 rounded-full border-2 border-blue-500 bg-white text-blue-500 hover:bg-blue-50"
										onClick={isRTL ? scrollNext : scrollPrev}
										disabled={isRTL ? !canScrollNext : !canScrollPrev}
									>
										<ArrowLeft className="h-5 w-5" />
									</Button>
								</motion.div>
								<motion.div
									whileHover={{ scale: 1.1 }}
									whileTap={{ scale: 0.9 }}
								>
									<Button
										variant="outline"
										size="icon"
										className="h-10 w-10 rounded-full border-2 border-blue-500 bg-white text-blue-500 hover:bg-blue-50"
										onClick={isRTL ? scrollPrev : scrollNext}
										disabled={isRTL ? !canScrollPrev : !canScrollNext}
									>
										<ArrowRight className="h-5 w-5" />
									</Button>
								</motion.div>
							</motion.div>
						</div>
					</BlurFade>

					{/* Wave Background */}
					<motion.div
						className="pointer-events-none absolute inset-0 z-0 overflow-hidden"
						initial={{ opacity: 0 }}
						animate={{ opacity: 1 }}
						transition={{ duration: 1, delay: 0.5 }}
					>
						<div className="absolute bottom-0 right-0 h-1/3 w-1/2 lg:-bottom-24 lg:h-2/3 lg:w-full">
							<Image
								src={"/wave.png"}
								alt="Wave background"
								fill
								quality={100}
								className="object-cover object-right-bottom"
								style={{
									maskImage:
										"linear-gradient(to left, rgba(0,0,0,1), rgba(0,0,0,0))",
									WebkitMaskImage:
										"linear-gradient(to left, rgba(0,0,0,1), rgba(0,0,0,0))",
								}}
							/>
						</div>
					</motion.div>
				</div>
			</div>
		</section>
	);
}

export default AboutClient;
